#!/usr/bin/python
#
# wander2.py
#
# Copyright 2017 William Henning
#
# Web site: http://Mikronauts.comimport RoboPiLib as RoboPi
#
# wander2 tests the 4WD motor library, which you need to calibrate with my minspeed utility
#
# Sadly cheap gear motors have significant variances from motor to motor.

import time as time

RoboPi.RoboPiInit("/dev/serial0",115200)

# verify connection
print RoboPi.getProductID()

sonar = 16      # HC-SR04 sersor

#------------------------------------------------------------------
#
# 4WD Motor API definitions for 2-pin motor drivers like L9110S
#
#------------------------------------------------------------------

# STARBOARD FRONT MOTOR

MA = 8  # Forward
MB = 9  # Reverse

MAF =  716 # Motor calibration value
MBF =  727 # Motor calibration value

# STARBOARD REAR MOTOR

MC = 10 # Forward
MD = 11 # Reverse

MCF =  711 # Motor calibration value
MDF =  701 # Motor calibration value

# PORT FRONT MOTOR

ME = 12 # Forward
MF = 13 # Reverse

MEF = 1000 # Motor calibration value
MFF =  930 # Motor calibration value

# PORT REAR MOTOR

MG = 14 # Forward
MH = 15 # Reverse

MGF =  752 # Motor calibration value
MHF =  657 # Motor calibration value

# initialize motors, all stopped

for pin in range(MA,MH+1):
  RoboPi.pinMode(pin,RoboPi.OUTPUT)
  RoboPi.analogWrite(pin,0)

def all_stop():
  for pin in range(MA,MH+1):
    RoboPi.analogWrite(pin,0)

def starboard_speed(fwd,rev):
  RoboPi.analogWrite(MA,(MAF*fwd)/1000)
  RoboPi.analogWrite(MB,(MBF*rev)/1000)
  RoboPi.analogWrite(MC,(MCF*fwd)/1000)
  RoboPi.analogWrite(MD,(MDF*rev)/1000)

def port_speed(fwd,rev):
  RoboPi.analogWrite(ME,(MEF*fwd)/1000)
  RoboPi.analogWrite(MF,(MFF*rev)/1000)
  RoboPi.analogWrite(MG,(MGF*fwd)/1000)
  RoboPi.analogWrite(MH,(MHF*rev)/1000)

def go_forward(speed):
  starboard_speed(speed,0)
  port_speed(speed,0)
  
def go_reverse(speed):
  starboard_speed(0,speed)
  port_speed(0,speed)
  
def turn_left(speed):
  starboard_speed(speed,0)
  port_speed(0,0)
  
def turn_right(speed):
  starboard_speed(0,0)
  port_speed(speed,0)

def spin_left(speed):
  starboard_speed(speed,0)
  port_speed(0,speed)
  
def spin_right(speed):
  starboard_speed(0,speed)
  port_speed(speed,0)

def wait(secs):
  done = time.time()+secs
  while time.time() < done:
    time.sleep(0.1)

speed = 250
  
# test each motor helper function

for loops in range(1,3):
  print "Loop", loops
  all_stop()  
  time.sleep(1)
  go_forward(speed)
  time.sleep(3)
  go_reverse(speed)
  time.sleep(3)
  turn_left(speed)
  time.sleep(3)
  turn_right(speed)
  time.sleep(3)
  spin_left(speed)
  time.sleep(3)
  spin_right(speed)
  time.sleep(3)

all_stop()

print "before"

# wander around the room avoiding obstacles
  
while (1):

  range = RoboPi.readDistance(sonar)
  
  if range > 0: # ignore bad 0 range readings
    print "Range: ", range
    if range < 50: # if closer than 20cm, spin left
      print "spin_left(speed)"
      spin_left(speed)
    else: # if 20cm or more range open, go forward
      go_forward(speed)
      print "forward(speed"


